from setuptools import setup, find_packages

setup(
    name="catrxneng",
    version="1.0.9",
    packages=find_packages(),
    install_requires=[],
    author="Gordon Brezicki",
    description="A collection of Python utilities for catalysis and reaction engineering",
    url="https://github.com/gbrezicki1/catrxneng",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
)
